@@ -97,18 +97,14 @@ class ModelSeeder(object):
 
         manager = self.model.objects.db_manager(using=using)
         turn_off_auto_add(manager.model)
-        tries = 0
         while True:
-            if tries == 3:
-                return None
             try:
-                tries += 1
                 obj = manager.create(**{
                     field: format_field(field_format, inserted_entities)
                     for field, field_format in self.field_formatters.items()
                 })
                 return obj.pk
-            except django.db.utils.IntegrityError as e:
+            except (django.db.utils.IntegrityError, django.db.utils.DataError) as e:
                 print(e)
                 continue
 
